@@ -10,6 +10,7 @@ from .forms import DingDingOptionsForm
 
 DingTalk_API = "https://oapi.dingtalk.com/robot/send?access_token={token}"
 
+print('version ===========> 0.1.3')
 
 class DingDingPlugin(NotificationPlugin):
     """
@@ -45,6 +46,7 @@ class DingDingPlugin(NotificationPlugin):
         Process error.
         """
         detail = event._data.data
+        print(event)
         if not self.is_configured(group.project):
             return
 
